/*  $Id: libinn.h,v 1.6 1999/04/08 10:48:52 src Exp $
 *
 *  extracted from INN version 2.0
 *
 *  $Log: libinn.h,v $
 *  Revision 1.6  1999/04/08 10:48:52  src
 *  Extendeddbz to configure
 *
 *  Revision 1.5  1998/09/21 10:33:32  src
 *  Getting rid of some warnings.
 *
 *  Revision 1.4  1998/09/14 06:13:52  src
 *  Picked RETSIGTYPE from config.h
 *
 *  Revision 1.3  1998/07/12 09:39:19  src
 *  NewsX version 1.0
 */

#ifndef _LIBINN_H
#define _LIBINN_H

typedef struct {
    char        hash[16];
} HASH;                         /* Hash */

/* Return the hash of a case mapped message-id */
HASH HashMessageID(const char *MessageID);

/* Convert hash to a form that we can use in error messages */
char *HashToText(const HASH hash);

/*EK*/
int SetNonBlocking(int fd, BOOL flag);
#endif
